==> tracker-0.7.13.tar.bz2: tracker-0.7.13/src/libtracker-common/tracker-utils.h <==
/*
 * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
 * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __LIBTRACKER_COMMON_UTILS_H__
#define __LIBTRACKER_COMMON_UTILS_H__

#include <glib.h>

G_BEGIN_DECLS

#if !defined (__LIBTRACKER_COMMON_INSIDE__) && !defined (TRACKER_COMPILATION)
#error "only <libtracker-common/tracker-common.h> must be included directly."
#endif

gboolean tracker_is_empty_string            (const char  *str);
gboolean tracker_is_blank_string            (const char  *str);
gchar *  tracker_string_replace             (const gchar *haystack,
                                             const gchar *needle,
                                             const gchar *replacement);
gchar *  tracker_string_remove              (gchar       *haystack,
                                             const gchar *needle);
gchar *  tracker_seconds_estimate_to_string (gdouble      seconds_elapsed,
                                             gboolean     short_string,
                                             guint        items_done,
                                             guint        items_remaining);
gchar *  tracker_seconds_to_string          (gdouble      seconds_elapsed,
                                             gboolean     short_string);
gchar *  tracker_coalesce                   (gint n_values,
                                             ...);
gchar *  tracker_merge                      (const gchar *delim, gint n_values,
                                             ...);

gchar *  tracker_text_normalize             (const gchar *text,
                                             guint        max_words,
                                             guint       *n_words);

/* Currently we define an alias here because right now we are using
 * GLib's escape functions, however, it is likely in the future that
 * Nepomuk's standard for URI escaping varies slightly and we want to
 * easily be able to have our own implementation without changing the
 * whole code base.
 */
#define  tracker_uri_printf_escaped         g_markup_printf_escaped

G_END_DECLS

#endif /* __LIBTRACKER_COMMON_UTILS_H__ */

==> tracker-0.7.23.tar.bz2: tracker-0.7.23/src/libtracker-common/tracker-utils.h <==
/*
 * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
 * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __LIBTRACKER_COMMON_UTILS_H__
#define __LIBTRACKER_COMMON_UTILS_H__

#include <glib.h>

G_BEGIN_DECLS

#if !defined (__LIBTRACKER_COMMON_INSIDE__) && !defined (TRACKER_COMPILATION)
#error "only <libtracker-common/tracker-common.h> must be included directly."
#endif

gboolean tracker_is_empty_string            (const char  *str);
gboolean tracker_is_blank_string            (const char  *str);
gchar *  tracker_string_replace             (const gchar *haystack,
                                             const gchar *needle,
                                             const gchar *replacement);
gchar *  tracker_string_remove              (gchar       *haystack,
                                             const gchar *needle);
gchar *  tracker_seconds_estimate_to_string (gdouble      seconds_elapsed,
                                             gboolean     short_string,
                                             guint        items_done,
                                             guint        items_remaining);
gchar *  tracker_seconds_to_string          (gdouble      seconds_elapsed,
                                             gboolean     short_string);
gchar*   tracker_uri_vprintf_escaped        (const gchar *format,
                                             va_list      args);
gchar*   tracker_uri_printf_escaped         (const gchar *format,
                                             ...);

G_END_DECLS

#endif /* __LIBTRACKER_COMMON_UTILS_H__ */
